.. rst-class:: detail

StopWatch
====================

.. currentmodule:: compas_rrc

.. autoclass:: StopWatch

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~StopWatch.__init__
        ~StopWatch.from_msg
    
    